@@ -29,14 +29,17 @@ pub mod managed;
 #[cfg_attr(docsrs, doc(cfg(feature = "unmanaged")))]
 pub mod unmanaged;
 
-// For handy re-usage in integration crates.
-#[cfg(feature = "managed")]
-#[doc(hidden)]
-pub use async_trait::async_trait;
-
 pub use deadpool_runtime::{Runtime, SpawnBlockingError};
 
 /// The current pool status.
+///
+/// **The status returned by the pool is not guaranteed to be consistent!**
+///
+/// While this features provides [eventual consistency][1] the numbers will be
+/// off when accessing the status of a pool under heavy load. These numbers
+/// are meant for an overall insight.
+///
+/// [1]: https://en.wikipedia.org/wiki/Eventual_consistency
 #[derive(Clone, Copy, Debug)]
 pub struct Status {
     /// The maximum size of the pool.
@@ -51,3 +54,5 @@ pub struct Status {
     /// The number of futures waiting for an object.
     pub waiting: usize,
 }
+
+mod util;
